package org.openxma.dsl.pom.formatting;

import org.eclipse.xtext.parsetree.AbstractNode;
import org.openxma.dsl.common.formatter.IFormatCondition;
import org.openxma.dsl.common.formatter.OpenXMAFormatter;
import org.openxma.dsl.common.formatter.OpenXMAFormattingConfig;
import org.openxma.dsl.core.model.Import;
import org.openxma.dsl.core.model.Model;
import org.openxma.dsl.pom.model.Command;
import org.openxma.dsl.pom.model.Component;
import org.openxma.dsl.pom.model.DataObjectVariable;
import org.openxma.dsl.pom.model.ObjectProperty;
import org.openxma.dsl.pom.model.Page;
import org.openxma.dsl.pom.model.XmadslPage;


public class PomDslOpenXMAFormatter extends OpenXMAFormatter {

	public void configureFormatting(OpenXMAFormattingConfig c) {
		org.openxma.dsl.pom.services.PomDslGrammarAccess f = (org.openxma.dsl.pom.services.PomDslGrammarAccess) getGrammarAccess();


		//c.setAutoLinewrap(120);
		c.setIndentationSpace("    ");
		
		// namespace
		c.setLinewrap(1).before(f.getModelAccess().getNamespaceKeyword_1_0());		

		c.setIndentation(
				f.getComponentAccess().getLeftCurlyBracketKeyword_6(),
				f.getComponentAccess().getRightCurlyBracketKeyword_15());

		c.setIndentation(
				f.getReferencedXMAPageAccess().getLeftCurlyBracketKeyword_6(),
				f.getReferencedXMAPageAccess().getRightCurlyBracketKeyword_14());

		c.setIndentation(
				f.getXmadslPageAccess().getLeftCurlyBracketKeyword_8(),
				f.getXmadslPageAccess().getRightCurlyBracketKeyword_16());

		c.setIndentation(
				f.getEventMappingListAccess().getLeftCurlyBracketKeyword_1(),
				f.getEventMappingListAccess().getRightCurlyBracketKeyword_3());

		c.setIndentation(
				f.getFlatCompositeContentAccess().getLeftCurlyBracketKeyword_1(),
				f.getFlatCompositeContentAccess().getRightCurlyBracketKeyword_3());

		c.setIndentation(
				f.getPartitionedCompositeContentAccess().getLeftCurlyBracketKeyword_1(),
				f.getPartitionedCompositeContentAccess().getRightCurlyBracketKeyword_3());

//		PageContent

		c.setIndentation(
				f.getTableAccess().getLeftCurlyBracketKeyword_8(),
				f.getTableAccess().getRightCurlyBracketKeyword_10());

		c.setIndentation(
				f.getTabFolderAccess().getLeftCurlyBracketKeyword_3(),
				f.getTabFolderAccess().getRightCurlyBracketKeyword_5());

		c.setIndentation(
				f.getTabPageAccess().getLeftCurlyBracketKeyword_5(),
				f.getTabPageAccess().getRightCurlyBracketKeyword_13());

		c.setLinewrap(1).before(f.getImportAccess().getRule(),new IFormatCondition() {
			public boolean applyFormat(AbstractNode node) {
				if (node.getElement() != null && node.getElement() instanceof Import) {
					Import imp = (Import)node.getElement();
					Model model = (Model)imp.eContainer();
					if (model.getImports().indexOf(imp)==0) return true;
				}
				return false;
			}
		});
		
		/* Splitpanel */		
		c.setLinewrap(1).after(f.getSplitPanelAccess().getLeftCurlyBracketKeyword_3());
		c.setLinewrap(1).before(f.getSplitPanelAccess().getSecondPanelXmadslCompositeParserRuleCall_5_0());			
		c.setLinewrap(1).before(f.getSplitPanelAccess().getRightCurlyBracketKeyword_6());		
		c.setIndentation(
				f.getSplitPanelAccess().getLeftCurlyBracketKeyword_3(),
				f.getSplitPanelAccess().getRightCurlyBracketKeyword_6());	
		c.setNoSpace().around(f.getSplitPanelAccess().getPercentSignParserRuleCall_2_1_3());	
		
		c.setLinewrap(1).before(f.getImportAccess().getImportKeyword_0_0());
		c.setLinewrap(1).before(f.getImportAccess().getImportKeyword_1_0());		
		c.setLinewrap(2).before(f.getModelElementAccess().getComponentParserRuleCall_0());
		c.setLinewrap(1).before(f.getComponentAccess().getCommandsCommandParserRuleCall_10_0());
		c.setLinewrap(2).before(f.getComponentAccess().getPagesPageParserRuleCall_13_0());
		c.setLinewrap(1).before(f.getComponentAccess().getRightCurlyBracketKeyword_15());
		
		c.setLinewrap(2).before(f.getTableCustomizerAccess().getTablecustomizerKeyword_0());		
				
		// Linewrap for each DataObjectVariable
		c.setLinewrap(1).before(f.getComponentAccess().getDataobjectsDataObjectVariableParserRuleCall_8_0());
		c.setLinewrap(1).before(f.getXmadslPageAccess().getDataobjectsDataObjectVariableParserRuleCall_10_0());		
		c.setLinewrap(1).before(f.getReferencedXMAPageAccess().getDataobjectsDataObjectVariableParserRuleCall_7_0());		
		
		// Extra linewrap is made for the first DataObjectVariable of a Component or a Page
		c.setLinewrap(1).before(f.getDataObjectVariableAccess().getRule(),new IFormatCondition() {			
			public boolean applyFormat(AbstractNode node) {				
				if (node.getElement() != null && node.getElement() instanceof DataObjectVariable) {
					DataObjectVariable v = (DataObjectVariable)node.getElement();
					if (v.eContainer() instanceof Component) {
						Component c = (Component)v.eContainer();
						int index = c.getDataobjects().indexOf(v);
						if (index == 0) return true;
					} else if (v.eContainer() instanceof Page) {
						Page c = (Page)v.eContainer();
						int index = c.getDataobjects().indexOf(v);
						if (index == 0) return true;
					}
				}
				return false;
			}
		});		

		//c.setLinewrap(2).before(f.getReferencedXMAPageAccess().getPageKeyword_0_0());
		c.setLinewrap(1).before(f.getReferencedXMAPageAccess().getRightCurlyBracketKeyword_14());
		c.setLinewrap(1).before(f.getReferencedXMAPageAccess().getCommandsCommandParserRuleCall_9_0());
		
		// Extra linewrap is made for the first Command of a Component or a Page
		c.setLinewrap(1).before(f.getCommandAccess().getRule(),				
				new IFormatCondition() {
					public boolean applyFormat(AbstractNode node) {
						if (node.getElement() != null && node.getElement() instanceof Command) {
							Command cmd = (Command)node.getElement();
							if (cmd.eContainer() instanceof Component) {
								Component c = (Component)cmd.eContainer();
								int index = c.getCommands().indexOf(cmd);
								if (index == 0) return true;
							} else if (cmd.eContainer() instanceof Page) {
								Page c = (Page)cmd.eContainer();
								int index = c.getCommands().indexOf(cmd);
								if (index == 0) return true;
							}
						}
						return false;
					}
				});

		c.setLinewrap(1).before(f.getXmadslPageAccess().getCommandsCommandParserRuleCall_12_0());
		c.setLinewrap(1).before(f.getXmadslPageAccess().getRightCurlyBracketKeyword_14_1_4());
		c.setLinewrap(1).before(f.getXmadslPageAccess().getRightCurlyBracketKeyword_16());		
		c.setLinewrap(2).before(f.getXmadslPageAccess().getEventsEventMappingListParserRuleCall_13_0_0());
		
		/* Conditions */
		c.setLinewrap(2).before(f.getXmadslPageAccess().getConditionsBlockConditionsBlockParserRuleCall_13_1_0());		
		c.setLinewrap(1).before(f.getConditionsBlockAccess().getStatusFlagsStatusFlagParserRuleCall_3_0());
		c.setLinewrap(1).before(f.getConditionsBlockAccess().getRightCurlyBracketKeyword_4());				
		c.setIndentation(
				f.getConditionsBlockAccess().getLeftCurlyBracketKeyword_2(),
				f.getConditionsBlockAccess().getRightCurlyBracketKeyword_4());
		
		/* Logic */
		c.setLinewrap(2).before(f.getXmadslPageAccess().getLogicBlockLogicBlockParserRuleCall_13_2_0());      
		c.setLinewrap(2).before(f.getLogicBlockAccess().getConditionedLogicConditionedLogicParserRuleCall_3_0());		
        c.setLinewrap(1).before(f.getLogicBlockAccess().getLogicItemLogicItemParserRuleCall_2_0());
        c.setLinewrap(1).before(f.getLogicBlockAccess().getRightCurlyBracketKeyword_4());       
        c.setLinewrap(1).before(f.getConditionedLogicAccess().getLogicItemLogicItemParserRuleCall_2_0());
        c.setIndentation(
                f.getLogicBlockAccess().getLeftCurlyBracketKeyword_1(),
                f.getLogicBlockAccess().getRightCurlyBracketKeyword_4());
        c.setNoSpace().around(f.getConditionedLogicAccess().getColonKeyword_1()); 
        c.setNoSpace().around(f.getColumnOrderAccess().getEqualsSignKeyword_1());
        c.setNoSpace().before(f.getColumnOrderAccess().getCommaKeyword_3_0());        
        c.setNoSpace().around(f.getColumnInfoAccess().getEqualsSignKeyword_1_0_1());        
        c.setNoSpace().before(f.getColumnInfoAccess().getRelativeWidthPercentSignParserRuleCall_1_0_3_0());     
        c.setNoSpace().around(f.getLabelTextAccess().getEqualsSignKeyword_0_0_1());        
        c.setNoSpace().around(f.getLabelTextAccess().getEqualsSignKeyword_1_1());        
		
		/* Variable */
		c.setNoSpace().around(f.getXmadslVariableAccess().getFullStopKeyword_1_0());
		
		/* ObjectProperties of Component and XmadslPage*/
		c.setLinewrap(1).before(f.getXmadslPageAccess().getPagePropertiesObjectPropertyParserRuleCall_9_0());
		c.setLinewrap(1).before(f.getComponentAccess().getComponentPropertiesObjectPropertyParserRuleCall_7_0());		
		c.setLinewrap(1).before(f.getObjectPropertyAccess().getRule(),new IFormatCondition() {
			public boolean applyFormat(AbstractNode node) {
				if (node.getElement() != null && node.getElement() instanceof ObjectProperty) {
					ObjectProperty imp = (ObjectProperty)node.getElement();
					if (imp.eContainer() instanceof Component) {					
						Component model = (Component)imp.eContainer();
						if (model.getComponentProperties().indexOf(imp)==0) return true;
					} else if (imp.eContainer() instanceof XmadslPage) {
						XmadslPage model = (XmadslPage)imp.eContainer();
						if (model.getPageProperties().indexOf(imp)==0) return true;						
					}
				}
				return false;
			}
		});													
		
		// Data binding
		c.setLinewrap(2).before(f.getXmadslPageAccess().getDataMappingDataMappingListParserRuleCall_11_0());	
		c.setLinewrap(1).before(f.getDataMappingListAccess().getMappingDataMappingParserRuleCall_2_0());		
		c.setLinewrap(1).before(f.getDataMappingListAccess().getRightCurlyBracketKeyword_3());
		c.setIndentation(
				f.getDataMappingListAccess().getMappingDataMappingParserRuleCall_2_0(),
				f.getDataMappingAccess().getFieldFieldReferenceParserRuleCall_2_0());				

		//c.setLinewrap(2).before(f.getEventMappingListAccess().getEventMappingKeyword_0_0());
		c.setLinewrap(1).before(f.getEventMappingListAccess().getRightCurlyBracketKeyword_3());

		c.setLinewrap(2).before(f.getReferencedXMAPageAccess().getEventsEventMappingListParserRuleCall_10_0_0());

		c.setLinewrap(1).before(f.getInitEventMappingAccess().getOnInitKeyword_0());
		c.setLinewrap(1).before(f.getEnterEventMappingAccess().getOnEnterKeyword_0());		
		c.setLinewrap(1).before(f.getLeaveEventMappingAccess().getOnLeaveKeyword_0());		
		c.setLinewrap(1).before(f.getXMAWidgetEventMappingAccess().getXmaKeyword_0());
		c.setLinewrap(1).before(f.getGuiElementEventMappingAccess().getControlIGuiElementWithEventCrossReference_0_0());

		c.setLinewrap(1).before(f.getContentPanelAccess().getReferencingPageCompositeContentKeyword_0_0());
		c.setLinewrap(1).before(f.getReferencedXMAPanelAccess().getPanelKeyword_0());
		c.setLinewrap(1).before(f.getReferencedXMAPartitionedPanelAccess().getHorizontalPartitioningHpanelKeyword_0_0_0());
		c.setLinewrap(1).before(f.getReferencedXMAPartitionedPanelAccess().getVerticalPartitioningVpanelKeyword_0_1_0());

		//c.setLinewrap(1).before(f.getPanelAccess().getPanelKeyword_0());
		//c.setLinewrap(1).before(f.getPartitionedPanelAccess().getHorizontalPartitioningHpanelKeyword_0_0_0());
		//c.setLinewrap(1).before(f.getPartitionedPanelAccess().getVerticalPartitioningVpanelKeyword_0_1_0());
		c.setLinewrap(1).before(f.getPartitionedCompositeContentAccess().getWidgetSetItemsSetOfComposedElementsParserRuleCall_2_0());
		//c.setLinewrap(1).before(f.getPartitionedCompositeContentAccess().getRightCurlyBracketKeyword_3());
		
		c.setLinewrap(1).before(f.getPageContentAccess().getElementsComposedElementParserRuleCall_0());		

		c.setLinewrap(1).before(f.getFlatCompositeContentAccess().getElementsComposedElementParserRuleCall_2_0());
		c.setLinewrap(1).before(f.getFlatCompositeContentAccess().getRightCurlyBracketKeyword_3());
		//c.setLinewrap(1).before(f.getPartitionedCompositeContentAccess().getWidgetSetItemsSetOfComposedElementsParserRuleCall_2_0());		
		c.setLinewrap(1).before(f.getPartitionedCompositeContentAccess().getRightCurlyBracketKeyword_3());

		//c.setLinewrap(1).before(f.getTableAccess().getTableKeyword_0());
		c.setLinewrap(1).before(f.getTableAccess().getRightCurlyBracketKeyword_10());
		c.setLinewrap(1).before(f.getTableAccess().getColumnsTableColumnParserRuleCall_9_0());

		//c.setLinewrap(1).before(f.getTabFolderAccess().getTabfolderKeyword_0());
		c.setLinewrap(1).before(f.getTabFolderAccess().getRightCurlyBracketKeyword_5());

		c.setLinewrap(1).before(f.getTabPageAccess().getTabpageKeyword_0());
		c.setLinewrap(1).before(f.getTabPageAccess().getRightCurlyBracketKeyword_13());
		
		// Cell
		c.setLinewrap(1).after(f.getSetOfComposedElementsAccess().getLeftCurlyBracketKeyword_0_2());		
		c.setLinewrap(1).before(f.getSetOfComposedElementsAccess().getRightCurlyBracketKeyword_0_4());		
		c.setLinewrap(1).before(f.getSetOfComposedElementsAccess().getElementsComposedElementParserRuleCall_0_3_0());		
		c.setIndentation(
			f.getSetOfComposedElementsAccess().getLeftCurlyBracketKeyword_0_2(),
			f.getSetOfComposedElementsAccess().getRightCurlyBracketKeyword_0_4());
		
		// Style
		c.setLinewrap(2).before(f.getStyleAccess().getRule());				
		c.setLinewrap(1).after(f.getStyleSpecificationAccess().getLeftCurlyBracketKeyword_4());		
		c.setLinewrap(1).before(f.getStyleSpecificationAccess().getRightCurlyBracketKeyword_6());
		c.setLinewrap(1).before(f.getStyleSpecificationAccess().getStylePropertyStyleSpecificationPropertyParserRuleCall_5_0());		
		c.setIndentation(
			f.getStyleSpecificationAccess().getLeftCurlyBracketKeyword_4(),
			f.getStyleSpecificationAccess().getRightCurlyBracketKeyword_6());
		c.setNoSpace().around(f.getStyleSpecificationAccess().getCommaKeyword_2_2_0());
		
		c.setNoSpace().around(f.getStyleSpecificationAccess().getCommaKeyword_3_2_0());
		
		// StyleSpecifications		
		c.setNoSpace().before(f.getStylePropertyFieldPartAccess().getColonKeyword_1());
		c.setNoSpace().before(f.getStylePropertyFieldPartAccess().getCommaKeyword_3_0());
		c.setNoSpace().before(f.getStylePropertyLeftAccess().getColonKeyword_1());		
		c.setNoSpace().before(f.getStylePropertyRightAccess().getColonKeyword_1());		
		c.setNoSpace().before(f.getStylePropertyTopAccess().getColonKeyword_1());		
		c.setNoSpace().before(f.getStylePropertyBottomAccess().getColonKeyword_1());		
		c.setNoSpace().before(f.getStylePropertyWidthAccess().getColonKeyword_1());		
		c.setNoSpace().before(f.getStylePropertyHeightAccess().getColonKeyword_1());		
		c.setNoSpace().before(f.getStylePropertyTabulatorAccess().getColonKeyword_1());		
		c.setNoSpace().around(f.getStylePropertyTabulatorAccess().getCommaKeyword_3_0());		
		c.setNoSpace().before(f.getStylePropertyBorderAccess().getColonKeyword_1());
		c.setNoSpace().around(f.getSelectedModelElementAccess().getPseudoClassAssignment_1_1());				
		c.setNoSpace().around(f.getSelectedModelElementAccess().getNumberSignKeyword_0_0_2_0());			
		c.setNoSpace().around(f.getSelectedModelElementAccess().getNumberSignKeyword_0_1_0());		
		c.setNoSpace().before(f.getStylePropertyForegroundColorAccess().getColonKeyword_1());
		c.setNoSpace().around(f.getStylePropertyForegroundColorAccess().getLeftParenthesisKeyword_2_0_1());
		c.setNoSpace().around(f.getStylePropertyForegroundColorAccess().getRightParenthesisKeyword_2_0_7());		
		c.setNoSpace().around(f.getStylePropertyForegroundColorAccess().getCommaKeyword_2_0_3());						
		c.setNoSpace().around(f.getStylePropertyForegroundColorAccess().getCommaKeyword_2_0_5());		
		c.setNoSpace().before(f.getStylePropertyBackgroundColorAccess().getColonKeyword_1());
		c.setNoSpace().around(f.getStylePropertyBackgroundColorAccess().getLeftParenthesisKeyword_2_0_1());
		c.setNoSpace().around(f.getStylePropertyBackgroundColorAccess().getRightParenthesisKeyword_2_0_7());				
		c.setNoSpace().around(f.getStylePropertyBackgroundColorAccess().getCommaKeyword_2_0_3());						
		c.setNoSpace().around(f.getStylePropertyBackgroundColorAccess().getCommaKeyword_2_0_5());			
		c.setNoSpace().before(f.getStylePropertyWidgetVariantAccess().getColonKeyword_1());		
		c.setNoSpace().before(f.getStylePropertyBrowseControlAccess().getColonKeyword_1());
		c.setNoSpace().before(f.getStylePropertyImageAccess().getColonKeyword_1());		
		
        // validatorref
        c.setNoSpace().around(f.getValidatorReferenceAccess().getLeftParenthesisKeyword_1_0());
        c.setNoSpace().around(f.getValidatorReferenceAccess().getCommaKeyword_1_1_1_0());
        c.setNoSpace().before(f.getValidatorReferenceAccess().getRightParenthesisKeyword_1_2());
        
        c.setNoSpace().before(f.getStylePropertyPagingControlsAccess().getCommaKeyword_3_0());        

		// []
		c.setNoSpace().before(f.getDataObjectVariableAccess().getIsCollectionLeftSquareBracketRightSquareBracketKeyword_2_0());

		// .
		c.setNoSpace().around(f.getGuiElementEventMappingAccess().getFullStopKeyword_1_0());
		c.setNoSpace().around(f.getGuiElementEventMappingAccess().getCommaKeyword_4_0());		

		/* CustomizeableField */
		c.setNoSpace().around(f.getCustomizeableFieldAccess().getFullStopKeyword_2());
		c.setNoSpace().around(f.getCustomizeableFieldAccess().getCommaKeyword_4_2_0());
		c.setNoSpace().around(f.getCustomizeableFieldAccess().getLeftSquareBracketKeyword_4_0());
		c.setNoSpace().around(f.getCustomizeableFieldAccess().getCommaKeyword_5_1_3_0());			
		c.setNoSpace().before(f.getCustomizeableFieldAccess().getLeftSquareBracketKeyword_4_0());	
		c.setNoSpace().around(f.getCustomizeableFieldAccess().getLeftParenthesisKeyword_0_0());		
		c.setNoSpace().around(f.getCustomizeableFieldAccess().getRightParenthesisKeyword_0_2());
		
		c.setNoSpace().around(f.getEditableFlagAccess().getEqualsSignKeyword_1());				
		c.setNoSpace().around(f.getVisibleFlagAccess().getEqualsSignKeyword_1());		
		c.setNoSpace().around(f.getEnabledFlagAccess().getEqualsSignKeyword_1());		
		c.setNoSpace().around(f.getMandatoryFlagAccess().getEqualsSignKeyword_1());		
				
		c.setNoSpace().around(f.getFieldReferenceAccess().getFullStopKeyword_1());		
		c.setNoSpace().around(f.getFieldFeatureAccess().getFullStopKeyword_1_0());		
		
		c.setNoSpace().around(f.getTabulatorPositionAccess().getColonKeyword_2_0_1());			

		c.setNoSpace().around(f.getTableAccess().getEqualsSignKeyword_3());
		c.setNoSpace().around(f.getTableAccess().getFullStopKeyword_5());		
//		c.setNoSpace().around(f.getTableAccess().getKeyAttributeHolderCrossReference_6_0());

		c.setNoSpace().before(f.getTableColumnAccess().getFullStopKeyword_0_0_0_1());
		c.setNoSpace().before(f.getTableColumnAccess().getFeatureFieldFeatureParserRuleCall_0_0_1_0());
		
		c.setNoSpace().around(f.getTableColumnAccess().getEqualsSignKeyword_1_0_1());		
		//c.setNoSpace().around(f.getTableColumnAccess().getEqualsSignKeyword_1_1_0_0_1());		
		//c.setNoSpace().around(f.getTableColumnAccess().getEqualsSignKeyword_1_1_0_1_1());		
		c.setNoSpace().around(f.getTableColumnAccess().getEqualsSignKeyword_1_3_1());		
		c.setNoSpace().around(f.getTableColumnAccess().getEqualsSignKeyword_1_4_1());		

		// TODO reactivate c.setNoSpace().around(f.getXmadslCompositeAccess().getEqualsSignKeyword_0_2_1_1());

		c.setNoSpace().around(f.getHeightPropertyAccess().getEqualsSignKeyword_1());
		c.setNoSpace().around(f.getWidthPropertyAccess().getEqualsSignKeyword_1());
		c.setNoSpace().around(f.getStylePropertyAccess().getEqualsSignKeyword_1());
		c.setNoSpace().around(f.getStylePropertyAccess().getCommaKeyword_3_0());		

		c.setNoSpace().around(f.getAttachmentPropertyAccess().getEqualsSignKeyword_1());
		c.setNoSpace().around(f.getAbsoluteSiblingAttachmentAccess().getFullStopKeyword_1_0());
		c.setNoSpace().around(f.getRelativeSiblingAttachmentAccess().getFullStopKeyword_1_0());
		c.setNoSpace().around(f.getOffsetAccess().getPlusSignKeyword_0_0_0());		
		c.setNoSpace().around(f.getOffsetAccess().getPlusSignKeyword_0_1_2_0_0());		
		c.setNoSpace().around(f.getOffsetAccess().getPlusSignKeyword_1_0_0());		
		c.setNoSpace().around(f.getOffsetAccess().getNegativeHyphenMinusKeyword_0_1_2_0_1_0());
        c.setNoSpace().around(f.getOffsetAccess().getNegativeHyphenMinusKeyword_1_0_1_0());		
		
		c.setNoSpace().around(f.getQualifiedNameAccess().getFullStopKeyword_1_0());		
		
		c.setNoSpace().around(f.getAlignmentPropertyAccess().getEqualsSignKeyword_1());
		c.setNoSpace().around(f.getPartitionedPanelAccess().getEqualsSignKeyword_3_1_1());
		c.setNoSpace().around(f.getPanelAccess().getEqualsSignKeyword_3_1_1());				

		// Attachments
		c.setNoSpace().around(f.getParentAttachmentAccess().getRelativePercentSignParserRuleCall_1_1_0_0());		
		c.setNoSpace().around(f.getTabulatorAttachmentAccess().getLeftParenthesisKeyword_1());				
		c.setNoSpace().before(f.getTabulatorAttachmentAccess().getRightParenthesisKeyword_3());			
		
		// ComposeData
		c.setNoSpace().around(f.getComposeDataAccess().getEqualsSignKeyword_0_1_0_0());		
		c.setNoSpace().around(f.getComposeDataAccess().getEqualsSignKeyword_1_1());		
		c.setNoSpace().around(f.getComposeDataAccess().getEqualsSignKeyword_2_1());		

		c.setNoSpace().around(f.getComposeDataAccess().getCommaKeyword_0_1_0_2_0());			
		c.setNoSpace().around(f.getComposeDataAccess().getCommaKeyword_1_4_0());	
		c.setNoSpace().around(f.getComposeDataAccess().getCommaKeyword_2_4_0());						

		// ::
		c.setNoSpace().around(f.getComponentAccess().getColonColonKeyword_2());
		c.setNoSpace().around(f.getReferencedXMAPageAccess().getColonColonKeyword_2());
		c.setNoSpace().around(f.getReferencedXMAPanelAccess().getColonColonKeyword_2());
		c.setNoSpace().around(f.getReferencedXMAPartitionedPanelAccess().getColonColonKeyword_2());
		
		// IncludePanel
        c.setNoSpace().around(f.getIncludePanelAccess().getXmaKeyword_2_0_2());     		
        c.setNoSpace().around(f.getIncludePanelAccess().getXmaKeyword_2_1_2());        
        c.setNoSpace().around(f.getIncludePanelAccess().getEqualsSignKeyword_2_0_1());        
        c.setNoSpace().around(f.getIncludePanelAccess().getEqualsSignKeyword_2_1_1());        
        c.setNoSpace().around(f.getIncludePanelAccess().getColonColonKeyword_2_0_3());        
        c.setNoSpace().around(f.getIncludePanelAccess().getColonColonKeyword_2_1_3());   
        
        /* Properties */
        c.setNoSpace().around(f.getLabelPropertyAccess().getEqualsSignKeyword_1());
        c.setNoSpace().around(f.getTooltipPropertyAccess().getEqualsSignKeyword_1());        
        c.setNoSpace().around(f.getUnitPropertyAccess().getEqualsSignKeyword_1());        

	}

}

